//Include the necessary libraries
#include <Wire.h>
#include <Sodaq_DS3231.h>

//These constants are used for reading the battery voltage
#define ADC_AREF 3.3
#define BATVOLTPIN A6
#define BATVOLT_R1 4.7
#define BATVOLT_R2 10

Sodaq_DS3231 RTC; //Create RTC object for DS3231 RTC come Temp Sensor 
//year, month, date, hour, min, sec and week-day(starts from 0 and goes to 6)
//writing any non-existent time-data may interfere with normal operation of the RTC.
//Take care of week-day also.*/
DateTime dt(2014, 06, 05, 11, 5, 00, 4);

void setup()
{
  //Start serial
  Serial.begin(9600);
  Serial.println("Date, Time, Temperature, Voltage");
  
  //Start the I2C protocol
  Wire.begin();
  
  //Initialise the DS3231 
  RTC.begin();
  //remember to comment this line once RTC is updated
  RTC.setDateTime(dt); //Adjust date-time as defined 'dt' above 
}
 
void loop()
{
  ///Read the temperature 
  RTC.convertTemperature();            
  float temp = RTC.getTemperature();
  
  // Convert temperature voltage to string
  char buffer[14]; //make buffer large enough for 7 digits
  String temperatureS = dtostrf(temp, 7,2,buffer);
  //'7' digits including '-' negative, decimal and white space. '2' decimal places
  temperatureS.trim(); //trim whitespace, important so Ubidots will treat it as a number
  
  //Read the voltage
  int mv = getRealBatteryVoltage() * 1000.0;
 
  String data = getDateTime()+ ", ";
  data += String(temperatureS)+ "C, ";
  data += String(mv)+ "mV";
  Serial.println(data);
}

String getDateTime()
{
  String dateTimeStr;
  
  //Create a DateTime object from the current time
  DateTime dt(RTC.makeDateTime(RTC.now().getEpoch()));

  //Convert it to a String
  dt.addToString(dateTimeStr);
  
  return dateTimeStr;  
}

float getRealBatteryVoltage()
{
  uint16_t batteryVoltage = analogRead(BATVOLTPIN);
  return (ADC_AREF / 1023.0) * (BATVOLT_R1 + BATVOLT_R2) / BATVOLT_R2 * batteryVoltage;
}
